================================
References for Physics/Mechanics
================================

.. [Kane1983] Kane, Thomas R., Peter W. Likins, and David A. Levinson.
        Spacecraft Dynamics. New York: McGraw-Hill Book, 1983. Print.
.. [Kane1985] Kane, Thomas R., and David A. Levinson. Dynamics, Theory and
        Applications. New York: McGraw-Hill, 1985. Print.
.. [Meijaard2007] Meijaard, J.P., Jim M. Papadopoulos, Andy Ruina, and A.L.
        Schwab. "Linearized Dynamics Equations for the Balance and Steer of a Bicycle:
        a Benchmark and Review." Proceedings of the Royal Society A: Mathematical,
        Physical and Engineering Sciences 463.2084 (2007): 1955-982. Print.
.. [WikiDyadics] "Dyadics." Wikipedia, the Free Encyclopedia. Web. 05 Aug.
        2011. <http://en.wikipedia.org/wiki/Dyadics>.
.. [WikiDyadicProducts] "Dyadic Product." Wikipedia, the Free Encyclopedia.
        Web. 05 Aug. 2011. <http://en.wikipedia.org/wiki/Dyadic_product>.
.. [Likins1973] Likins, Peter W. Elements of Engineering Mechanics.
        McGraw-Hill, Inc. 1973. Print.
